@@ -51,17 +51,17 @@ map_errors = {
 }
 arg_tz = pytz.timezone('America/Buenos_Aires')
 
-def frmat_card(response):
+def _format_card(response):
     if 'card' in response:
         return {
             'id': response['card']['id'],
             'card_type': 'not_found',
-           'last_four_digits': response['card']['last_four_digits'],
+            'last_four_digits': response['card']['last_four_digits'],
             'cardholder': {
                 'name': response['card']['cardholder']['name']
             },
             'expiration_month': response['card']['expiration_month'],
-        'expiration_year': response['card']['expiration_year'],
+            'expiration_year': response['card']['expiration_year'],
         }
         
     if 'card_data' in response and 'tokens' not in response['card_data']:
